@@ -1,4 +1,4 @@
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 import logging
 from logging.handlers import RotatingFileHandler
@@ -71,7 +71,7 @@ def get_logger(
         handler.setLevel(level)
         handler.setFormatter(CustomFormatter(colored=colored))
         handlers.append(handler)
-    if "file" in handler_list and filepath is None:
+    if "file" in handler_list and filepath is not None:
         handler = RotatingFileHandler(
             filepath, maxBytes=(1 * 100 * 1024 * 1024), backupCount=10
         )
